yamlx

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 26, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package yamlx contains convenience utilities for yaml.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Unmarshal

func Unmarshal[T any](data []byte) (T, error)

Unmarshal deserializes data from YAML to a variable of some type

func UnmarshalFromFile

func UnmarshalFromFile[T any](filename string) (T, error)

UnmarshalFromFile reads and unmarshals a yaml file.

func UnmarshalStrict

func UnmarshalStrict[T any](data []byte) (T, error)

UnmarshalStrict deserializes data from YAML to a variable of some type. Fails if there are unknown fields in the data.

func UnmarshalStrictFromFile

func UnmarshalStrictFromFile[T any](filename string) (T, error)

UnmarshalStrictFromFile reads and unmarshals a yaml file. Fails if there are unknown fields in the data.

Types

This section is empty.

Jump to