Documentation
¶
Overview ¶
Package yamlx contains convenience utilities for yaml.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func UnmarshalFromFile ¶
UnmarshalFromFile reads and unmarshals a yaml file.
func UnmarshalStrict ¶
UnmarshalStrict deserializes data from YAML to a variable of some type. Fails if there are unknown fields in the data.
func UnmarshalStrictFromFile ¶
UnmarshalStrictFromFile reads and unmarshals a yaml file. Fails if there are unknown fields in the data.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.